<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>Arqiver::AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="160"/>
        <source>License</source>
        <translation>Άδεια</translation>
    </message>
</context>
<context>
    <name>Arqiver::Backend</name>
    <message>
        <location filename="../../backends.cpp" line="840"/>
        <source>This file is a link but its target does not exist.</source>
        <translation>Αυτό το αρχείο είναι ένας σύνδεσμος αλλά ο προορισμός του δεν υπάρχει.</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1261"/>
        <location filename="../../backends.cpp" line="1293"/>
        <location filename="../../backends.cpp" line="1337"/>
        <source>Could not read archive</source>
        <translation>Αδυναμία ανάγνωσης αρχείου</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1296"/>
        <location filename="../../backends.cpp" line="1342"/>
        <source>Archive Loaded</source>
        <translation>Το αρχείο φορτώθηκε</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1303"/>
        <location filename="../../backends.cpp" line="1390"/>
        <source>Modification Finished</source>
        <translation>Η τροποποίηση ολοκληρώθηκε</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1324"/>
        <location filename="../../backends.cpp" line="1359"/>
        <source>Extraction Finished</source>
        <translation>Η εξαγωγή ολοκληρώθηκε</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1327"/>
        <location filename="../../backends.cpp" line="1378"/>
        <source>Extraction Failed</source>
        <translation>Η εξαγωγή απέτυχε</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1475"/>
        <source>%1 is missing from your system.
Please install it for this kind of archive!</source>
        <translation>Το %1 λείπει από το σύστημά σας.
Παρακαλούμε εγκαταστήστε το για αυτό το είδος αρχείου!</translation>
    </message>
</context>
<context>
    <name>Arqiver::LineEdit</name>
    <message>
        <location filename="../../lineedit.h" line="33"/>
        <source>You could type inside the main view.
Clear text with the Escape key.</source>
        <translation>Θα μπορούσατε να πληκτρολογήσετε εντός της κύριας προβολής.
Εκκαθάριση κειμένου με το πλήκτρο Escape.</translation>
    </message>
</context>
<context>
    <name>Arqiver::PrefDialog</name>
    <message>
        <location filename="../../pref.ui" line="14"/>
        <source>Preferences</source>
        <translation>Προτιμήσεις</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="50"/>
        <source>Start with this size:</source>
        <translation>Εκκίνηση με αυτό το μέγεθος:</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="118"/>
        <source>Use system icons where possible</source>
        <translation>Χρήση εικονιδίων συστήματος όπου είναι δυνατό</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="125"/>
        <source>Show prompt on removing items</source>
        <translation>Εμφάνιση ερώτησης κατά την αφαίρεση στοιχείων</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="132"/>
        <source>If this is unchecked, only the top level directories will be expanded.</source>
        <translation>Αν αυτό αποεπιλεγεί, οι κατάλογοι μόνο του ανωτάτου επιπέδου θα αναπτυχθούν.</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="135"/>
        <source>Expand all directories when opening archives</source>
        <translation>Ανάπτυξη όλων των καταλόγων κατά το άνοιγμα αρχείων</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="147"/>
        <location filename="../../pref.ui" line="160"/>
        <source>Leave empty for the default.

Warning: Arqiver will not work if the
binary does not belong to libarchive.</source>
        <translation>Αφήστε κενό για την προεπιλογή.

Προειδοποίηση: Το Arqiver δε θα λειτουργήσει αν
το δυαδικό δεν ανήκει στο libarchive.</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="153"/>
        <source>libarchive binary:</source>
        <translation>δυαδικό libarchive:</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="38"/>
        <source>Remember window &amp;size on closing</source>
        <translation>Απομνημόνευση παραθύρου &amp;μεγέθους κατά το κλείσιμο</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="93"/>
        <source>Size of view icons:</source>
        <translation>Μέγεθος προβολής εικονιδίων:</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="62"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="184"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation>Χρειάζεται επανεκκίνηση της εφαρμογής για να τεθούν σε ισχύ οι αλλαγές.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="241"/>
        <source>Select libarchive binary</source>
        <translation>Επιλογή δυαδικού libarchive</translation>
    </message>
</context>
<context>
    <name>Arqiver::mainWin</name>
    <message>
        <location filename="../../mainWin.ui" line="53"/>
        <source>Archive:</source>
        <translation>Αρχείο:</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="106"/>
        <source>Filter Files...</source>
        <translation>Φιλτράρισμα αρχείων...</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="129"/>
        <source>&amp;File</source>
        <translation>&amp;Αρχείο</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="140"/>
        <source>&amp;Edit</source>
        <translation>&amp;Επεξεργασία</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="155"/>
        <source>&amp;View</source>
        <translation>&amp;Εμφάνιση</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="166"/>
        <source>&amp;Help</source>
        <translation>&amp;Βοήθεια</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="204"/>
        <source>&amp;Open Archive</source>
        <translation>&amp;Άνοιγμα αρχείου</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="207"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="212"/>
        <source>&amp;New Archive</source>
        <translation>&amp;Νέο αρχείο</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="215"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="220"/>
        <source>&amp;Quit</source>
        <translation>&amp;Τερματισμός</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="223"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="228"/>
        <source>Add File(s)</source>
        <translation>Προσθήκη αρχείου(ων)</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="233"/>
        <source>Remove File(s)</source>
        <translation>Αφαίρεση αρχείου(ων)</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="238"/>
        <source>Extract All</source>
        <translation>Εξαγωγή όλων</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="241"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="246"/>
        <source>Add Directory</source>
        <translation>Προσθήκη καταλόγου</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="251"/>
        <source>Extract Selection</source>
        <translation>Εξαγωγή επιλογής</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="256"/>
        <source>Set Password</source>
        <translation>Ορισμός κωδικού πρόσβασης</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="261"/>
        <source>E&amp;xpand</source>
        <translation>Α&amp;νάπτυξη</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="264"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Κάτω</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="269"/>
        <source>Collap&amp;se</source>
        <translation>Σύμπτ&amp;υξη</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="272"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Πάνω</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="277"/>
        <source>&amp;About</source>
        <translation>&amp;Σχετικά</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="282"/>
        <source>&amp;Copy Current Path</source>
        <translation>&amp;Αντιγραφή τρέχουσας διαδρομής</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="287"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Προτιμήσεις</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="292"/>
        <source>Stop &amp;Process</source>
        <translation>Διακοπή &amp;διεργασίας</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="295"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="305"/>
        <source>Update Archive</source>
        <translation>Ενημέρωση αρχείου</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="147"/>
        <source>Root</source>
        <translation>Ρίζα</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="252"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="323"/>
        <source>File</source>
        <translation>Αρχείο</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="323"/>
        <source>MimeType</source>
        <translation>Τύπος mime</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="323"/>
        <source>Size</source>
        <translation>Μέγεθος</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="553"/>
        <location filename="../../mainWin.cpp" line="838"/>
        <location filename="../../mainWin.cpp" line="882"/>
        <source>Opening Archive...</source>
        <translation>Άνοιγμα αρχείου...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="767"/>
        <source>Create Archive</source>
        <translation>Δημιουργία αρχείου</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="464"/>
        <location filename="../../mainWin.cpp" line="793"/>
        <location filename="../../mainWin.cpp" line="992"/>
        <location filename="../../mainWin.cpp" line="1300"/>
        <source>Question</source>
        <translation>Ερώτηση</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="794"/>
        <source>The following archive already exists:</source>
        <translation>Το ακόλουθο αρχείο υπάρχει ήδη:</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="796"/>
        <source>Do you want to replace it?
</source>
        <translation>Θέλετε να το αντικαταστήσετε;
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="830"/>
        <source>Open Archive</source>
        <translation>Άνοιγμα αρχείου</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="897"/>
        <location filename="../../mainWin.cpp" line="904"/>
        <location filename="../../mainWin.cpp" line="941"/>
        <source>Add to Archive</source>
        <translation>Προσθήκη σε αρχείο</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="936"/>
        <location filename="../../mainWin.cpp" line="967"/>
        <location filename="../../mainWin.cpp" line="1252"/>
        <location filename="../../mainWin.cpp" line="1258"/>
        <source>Adding Items...</source>
        <translation>Προσθήκη στοιχείων...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="993"/>
        <source>Do you want to remove the selected item(s)?
</source>
        <translation>Θέλετε να αφαιρέσετε το(α) επιλεγμένο(α) στοιχείο(α);
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1012"/>
        <source>Removing Items...</source>
        <translation>Αφαίρεση στοιχείων...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1215"/>
        <location filename="../../mainWin.cpp" line="1230"/>
        <location filename="../../mainWin.cpp" line="1315"/>
        <location filename="../../mainWin.cpp" line="1329"/>
        <source>Extracting...</source>
        <translation>Εξαγωγή...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1056"/>
        <source>Copy Archive Path</source>
        <translation>Αντιγραφή διαδρομής αρχείου</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="465"/>
        <source>Some files have been modified.</source>
        <translation>Κάποια αρχεία έχουν τροποποιηθεί.</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="466"/>
        <source>Do you want to ignore the changes?
</source>
        <translation>Θέλετε να αγνοήσετε τις αλλαγές;
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="627"/>
        <source>All Types</source>
        <translation>Όλοι οι τύποι</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="637"/>
        <location filename="../../mainWin.cpp" line="661"/>
        <source>Uncompressed Archive</source>
        <translation>Μη συμπιεσμένο αρχείο</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="638"/>
        <location filename="../../mainWin.cpp" line="662"/>
        <source>GZip Compressed Archive</source>
        <translation>Συμπιεσμένο αρχείο GZip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="639"/>
        <location filename="../../mainWin.cpp" line="663"/>
        <location filename="../../mainWin.cpp" line="664"/>
        <source>BZip Compressed Archive</source>
        <translation>Συμπιεσμένο αρχείο BZip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="640"/>
        <location filename="../../mainWin.cpp" line="665"/>
        <source>BZip2 Compressed Archive</source>
        <translation>Συμπιεσμένο αρχείο BZip2</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="641"/>
        <location filename="../../mainWin.cpp" line="673"/>
        <source>LMZA Compressed Archive</source>
        <translation>Συμπιεσμένο αρχείο LMZA</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="642"/>
        <location filename="../../mainWin.cpp" line="670"/>
        <source>XZ Compressed Archive</source>
        <translation>Συμπιεσμένο αρχείο XZ</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="643"/>
        <location filename="../../mainWin.cpp" line="674"/>
        <source>Zstandard Compressed Archive</source>
        <translation>Συμπιεσμένο αρχείο Zstandard</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="644"/>
        <location filename="../../mainWin.cpp" line="676"/>
        <source>CPIO Archive</source>
        <translation>Αρχείο CPIO</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="646"/>
        <location filename="../../mainWin.cpp" line="678"/>
        <source>AR Archive</source>
        <translation>Αρχείο AR</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="648"/>
        <location filename="../../mainWin.cpp" line="680"/>
        <source>Zip Archive</source>
        <translation>Αρχείο Zip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="649"/>
        <location filename="../../mainWin.cpp" line="682"/>
        <source>Gzip Archive</source>
        <translation>Αρχείο Gzip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="650"/>
        <location filename="../../mainWin.cpp" line="681"/>
        <source>7-Zip Archive</source>
        <translation>Αρχείο 7-Zip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="666"/>
        <location filename="../../mainWin.cpp" line="667"/>
        <source>READ-ONLY: BZip Archive</source>
        <translation>ΑΝΑΓΝΩΣΗ-ΜΟΝΟ: Αρχείο BZip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="668"/>
        <source>READ-ONLY: BZip2 Archive</source>
        <translation>ΑΝΑΓΝΩΣΗ-ΜΟΝΟ: Αρχείο BZip2</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="669"/>
        <source>READ-ONLY: BZip2 Compressed PDF Document</source>
        <translation>ΑΝΑΓΝΩΣΗ-ΜΟΝΟ: Συμπιεσμένο BZip2 έγγραφο PDF</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="671"/>
        <source>READ-ONLY: XZ archive</source>
        <translation>ΑΝΑΓΝΩΣΗ-ΜΟΝΟ: Αρχείο XZ</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="672"/>
        <source>READ-ONLY: XZ Compressed PDF Document</source>
        <translation>ΑΝΑΓΝΩΣΗ-ΜΟΝΟ: Συμπιεσμένο XZ έγγραφο PDF</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="675"/>
        <source>READ-ONLY: Zstandard archive</source>
        <translation>ΑΝΑΓΝΩΣΗ-ΜΟΝΟ: Αρχείο Zstandard</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="683"/>
        <source>Gzip Compressed PDF Document</source>
        <translation>Συμπιεσμένο Gzip έγγραφο PDF</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="684"/>
        <source>READ-ONLY: Compressed SVG Image</source>
        <translation>ΑΝΑΓΝΩΣΗ-ΜΟΝΟ: Συμπιεσμένη εικόνα SVG</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="685"/>
        <location filename="../../mainWin.cpp" line="686"/>
        <location filename="../../mainWin.cpp" line="687"/>
        <location filename="../../mainWin.cpp" line="688"/>
        <source>READ-ONLY: ISO Image</source>
        <translation>ΑΝΑΓΝΩΣΗ-ΜΟΝΟ: Είδωλο ISO</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="689"/>
        <source>READ-ONLY: XAR Archive</source>
        <translation>ΑΝΑΓΝΩΣΗ-ΜΟΝΟ: Αρχείο XAR</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="690"/>
        <source>READ-ONLY: Java Archive</source>
        <translation>ΑΝΑΓΝΩΣΗ-ΜΟΝΟ: Αρχείο Java</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="691"/>
        <source>READ-ONLY: Debian Package</source>
        <translation>ΑΝΑΓΝΩΣΗ-ΜΟΝΟ: Πακέτο Debian</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="692"/>
        <location filename="../../mainWin.cpp" line="693"/>
        <source>READ-ONLY: RedHat Package</source>
        <translation>ΑΝΑΓΝΩΣΗ-ΜΟΝΟ: Πακέτο RedHat</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="694"/>
        <location filename="../../mainWin.cpp" line="695"/>
        <location filename="../../mainWin.cpp" line="696"/>
        <source>READ-ONLY: MS Windows Executable</source>
        <translation>ΑΝΑΓΝΩΣΗ-ΜΟΝΟ: Εκτελέσιμο MS Windows</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="697"/>
        <source>READ-ONLY: MS Windows Installer Package</source>
        <translation>ΑΝΑΓΝΩΣΗ-ΜΟΝΟ: Πακέτο εγκατάστασης MS Windows</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="698"/>
        <source>READ-ONLY: MS Windows Cabinet Archive</source>
        <translation>ΑΝΑΓΝΩΣΗ-ΜΟΝΟ: Αρχείο αρχειοθήκης MS Windows</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="700"/>
        <source>READ-ONLY: Android Package</source>
        <translation>ΑΝΑΓΝΩΣΗ-ΜΟΝΟ: Πακέτο Android</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="701"/>
        <source>READ-ONLY: RAR Archive</source>
        <translation>ΑΝΑΓΝΩΣΗ-ΜΟΝΟ: Αρχείο RAR</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="702"/>
        <source>READ-ONLY: AppImage application bundle</source>
        <translation>ΑΝΑΓΝΩΣΗ-ΜΟΝΟ: Πακέτο εφαρμογής AppImage</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="703"/>
        <source>READ-ONLY: VirtualBox Extension Pack</source>
        <translation>ΑΝΑΓΝΩΣΗ-ΜΟΝΟ: Πακέτο επεκτάσεων VirtualBox</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="712"/>
        <source>All Known Types</source>
        <translation>Όλοι οι γνωστοί τύποι</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="717"/>
        <source>Show All Files</source>
        <translation>Εμφάνιση όλων των αρχείων</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1066"/>
        <source>Open Containing Folder</source>
        <translation>Άνοιγμα περιέχοντος φακέλου</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="300"/>
        <source>View Current Item</source>
        <translation>Προβολή τρέχοντος στοιχείου</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1111"/>
        <location filename="../../mainWin.cpp" line="1119"/>
        <source>Enter Password</source>
        <translation>Εισαγωγή κωδικού πρόσβασης</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1127"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1132"/>
        <source>OK</source>
        <translation>Εντάξει</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1136"/>
        <source>Encrypt the file list</source>
        <translation>Κρυπτογράφηση της λίστας αρχείων</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1137"/>
        <source>This will take effect after files/folders are added.</source>
        <translation>Αυτό θα τεθεί σε ισχύ αφότου προστεθούν αρχεία/φάκελοι.</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1208"/>
        <location filename="../../mainWin.cpp" line="1284"/>
        <source>Extract Into Directory</source>
        <translation>Εξαγωγή σε κατάλογο</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1301"/>
        <source>Some files will be overwritten.
Do you want to continue?
</source>
        <translation>Κάποια αρχεία θα αντικατασταθούν.
Θέλετε να συνεχίσετε;
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1427"/>
        <source>Link To: %1</source>
        <translation>Σύνδεσμος σε: %1</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1694"/>
        <source>Could not read archive</source>
        <translation>Αδυναμία ανάγνωσης αρχείου</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1765"/>
        <source>A simple Qt archive manager</source>
        <translation>Ένας απλός διαχειριστής αρχείων Qt</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1766"/>
        <source>based on libarchive, gzip and 7z</source>
        <translation>βασισμένο σε libarchive, gzip και 7z</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1767"/>
        <source>Author</source>
        <translation>Συντάκτης</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1768"/>
        <source>aka.</source>
        <translation>επίσης γνωστό ως</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1769"/>
        <location filename="../../mainWin.cpp" line="1770"/>
        <source>About Arqiver</source>
        <translation>Σχετικά με το Arqiver</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1769"/>
        <source>Translators</source>
        <translation>Μεταφραστές</translation>
    </message>
</context>
</TS>
